Processor.App.Extractor.extractor.BaseExtractor.preprocess
==========================================================

.. currentmodule:: Processor.App.Extractor.extractor

.. automethod:: BaseExtractor.preprocess